import { Role } from "discord.js";

import { Moderator } from "../Moderator";

import { GuildMute } from "../ModeratorDatabase";
import { CreationMuteOptions, DefaultObject, ModeratorGuild } from "../ModeratorData";
import { CreateMuteOptions, DeleteMuteOptions, FetchOptions, ListOptions, Options, SetMuteRoleOptions } from "../Options";

export declare class MuteManager {
    constructor(moderator: Moderator);

    private moderator: Moderator;

    /**
     * Method for setting the server role mute
     * 
     * @param options Set mute role options
     * 
     * @returns Returns the state of action execution
     */
    public setRole(options: Options<SetMuteRoleOptions>): Promise<DefaultObject>;

    /**
     * A method to get a server role mute
     * 
     * @param guild Discord Guild Object or ID
     * 
     * @returns Returns server mute role or object with error
     */
    public getRole(guild: ModeratorGuild): Promise<Role & DefaultObject>;

    /**
     * Method for removing the server role mute
     * 
     * @param guild Discord Guild Object or ID
     * 
     * @returns Returns the state of action execution
     */
    public deleteRole(guild: ModeratorGuild): Promise<DefaultObject>;

    /**
     * Method for issuing a muth to a Discord Guild user
     * 
     * @param options Create mute options
     * 
     * @returns Returns an object with muta data or an object with an error
     */
    public create(options: Options<CreateMuteOptions>): Promise<GuildMute & DefaultObject>;

    /**
     * A method for obtaining data on the user's mute on the Discord guild
     * 
     * @param options Fetch options
     * 
     * @returns Returns information about a mute or an object with an error
     */
    public get(options: Options<FetchOptions>): Promise<GuildMute & DefaultObject>;

    /**
     * A method for obtaining an array of mutes of a specific Discord guild or user from it
     * 
     * @param options Fetch options
     * 
     * @returns Returns an array of Discord mutes of a guild or user
     */
    public list(options: Options<ListOptions>): Promise<Array<GuildMute>>;

    /**
     * A method for removing muths from Discord guild users
     * 
     * @param options Delete mute options
     * 
     * @returns Returns the state of the action or an object with an error
     */
    public delete(options: Options<DeleteMuteOptions>): Promise<DefaultObject>;
}